@@ -10,15 +10,13 @@ import sys
 
 app_name = get_app_name()
 args = get_args()
-# args.remove(app_name)
 
 def main():
     if (is_name_valid(app_name)):
-        # validate all arguments first!!
 
+        # validate all arguments first!!
         if(is_args_valid(args)):
             
-            print(';;;;;;;;;;')
             # Create folder with app_name
             create_dir(app_name)
 
