@@ -12,7 +12,6 @@ valid_args_list = ['-d','--debugger', '-cj', '--css-js', '-dc', '--docker-contai
 def get_app_name():
   try:
       app_name = sys.argv[1]
-      print("NAME: " + app_name)
   except:
       print('App name cannot be empty. Please consider using --help')
       empty_name()
@@ -35,10 +34,6 @@ def is_args_valid(args):
   valid_args =  all(arg in valid_args_list for arg in args)
   return valid_args
 
-def validate_args(args):
-  print(args)
-  print('test')
-
 # create directory for application
 def create_dir(app_name):
   try:
